const { Calendar, DateHelper, StringHelper, DomClassList } = bryntum.calendar;

let tickWidth = 50;

let allNonWorkingDays = [
    { id: 'r1', nonWorkingDays: [0, 6, /*Put today day number here (0->Sunday, 1->Monday, ...)*/3] },
    { id: 'r2', nonWorkingDays: [0, 6] },
]

let eventEdit = {
    editorConfig: {
        modal: true,
        centered: true,
        anchor: null
    },
    items: {
        startDateField: {
            format:'DD/MM/YYYY'
        },
        endDateField: {
            format: 'DD/MM/YYYY'
        },resourceBarFilter: {
            // Inserts just before the resourceFilter List
            weight: 190,

            // Shows a clear trigger
            clearable: true,

            cls: 'filterFields',
            placeholder: 'Filter resources',
            type: 'textfield',
            keyStrokeChangeDelay: 100
        },
        resourceField: {
            multiSelect: true,
            selectAllItem: true,
            toggleAllfCtrlPressed: true,

            valueField: null,

            masterFilter: () => true
        },
        exportButton: {
            type: 'button',
            icon: 'b-fa b-fa-calendar-alt',
            text: 'Ajouter à Outlook (.ics)',
            weight: 900,
            onClick() {
                const eventRecord = privates.calendar.features.eventEdit.eventRecord;

                // Add some custom ICS values (See https://tools.ietf.org/html/rfc5545 for more information)
                eventRecord.exportToICS({
                    LOCATION: eventRecord.location
                });
            }
        }
    }
};

let sidebarItems = {
    datePicker: {
        weekStartDay: 1
    },
    eventFilter: {},
    resourceBarFilter: {
        // Inserts just before the resourceFilter List
        weight: 190,

        // Shows a clear trigger
        clearable: true,

        placeholder: 'Ressources',
        type: 'textfield',
        keyStrokeChangeDelay: 100,
    },
    resourceFilter: {
        multiSelect: true,
        selectAllItem: true,
        toggleAllfCtrlPressed: true
    }
}

let resources = [
    { id: 'r1', name: 'Google', eventColor: 'blue', isDefault: true },
    { id: 'r2', name: 'Bryntum', eventColor: 'red', isDefault: false }
];
let events = [];
let assignments = [];

const eventStore = new bryntum.calendar.EventStore({
    data: events
});
const resourceStore = new bryntum.calendar.ResourceStore({
    data: resources,
    sorters: [
        {field: 'name', ascending: true}
    ]
});
const assignmentStore = new bryntum.calendar.AssignmentStore({
    data: assignments
});

const project = new bryntum.calendar.ProjectModel({
    resourceStore: resourceStore,
    eventStore: eventStore,
    assignmentStore: assignmentStore
});

const calendar = new Calendar({
    minHeight: 525,
    //height: window.innerHeight - $('.navbar').outerHeight() - $('.navbarsavemenu').outerHeight() - $('footer').outerHeight(),

    project: project,

    modes: {
        week: {
            hideNonWorkingDays: true
        }
    },

    mode: "week",

    modeDefaults: {
        autoCreate: {
            newName: ' '
        }
    },

    sidebar: {
        items: sidebarItems
    },

    // Features named by the properties are included.
    // An object is used to configure the feature.
    features: {
        print: true,
        eventTooltip: {
            // Because we're using a context menu with an active trigger action,
            // we show the tooltip on hover (default is on click).
            showOn: 'hover',

            // Configuration options are passed on to the tooltip instance.
            // Because we are using a context menu too, keep the tooltip
            // out of the way above the event (if possible - it will try
            // other orientations if there's not enough space there).
            align: 'b-t'
        },
        eventEdit: eventEdit,
        scheduleMenu: {
            items: {
                addEvent: {}
            }
        },
        eventMenu: {
            items: {
                editEvent: {},
                deleteEvent: {}
            }
        }
    },

    // Called as the resourceFilterFilter's onChange handler
    onResourceFilterFilterChange({ value }) {
        // A filter with an id replaces any previous filter with that id.
        // Leave any other filters which may be in use in place.
        this.widgetMap.resourceFilter.store.filter({
            id: 'resourceBarFilter',
            filterBy: r => r.name.toLowerCase().startsWith(value.toLowerCase()) // a function which returns true to include the record
        });
    },

    // This element becomes the Calendar's encapsulating element
    appendTo: 'agenda'
});

const { resourceFilter } = calendar.widgetMap;

calendar.resourceFilter = calendar.eventStore.addFilter({
    id: 'custom-filter',
    filterBy: event => {
        let assign = null;
        calendar.assignmentStore._data.every(function (assignment) {
            if (assignment.eventId === event.data.id || assignment.eventId === event.data.eventId)
                assign = assignment;
            return assign === null;
        });
        let res = null;
        calendar.resourceStore._data.every(function (resource) {
            if (resource.id === assign.resourceId)
                res = resource;
            return res === null;
        });

        return res.isDefault;
    }
});

resourceFilter.value = [resourceFilter.store._data.find((a) => a.isDefault)];

let items = document.getElementsByClassName('b-list-item')
for (let item of items) {
    item.onclick = function () {
        setTimeout(function () {
            let selected = document.querySelectorAll('.b-list-item.b-selected')
            let nbSelected = selected.length;
            if (nbSelected === 1) {
                let selectedId = selected[0].dataset.id;
                let nonWorkingDaysRaw = allNonWorkingDays.find((u) => u.id === selectedId).nonWorkingDays,
                    nonWorkingDays = {};
                nonWorkingDaysRaw.forEach(function (key) {
                    nonWorkingDays[key] = true;
                });
                calendar.nonWorkingDays = nonWorkingDays;
            } else {
                calendar.nonWorkingDays = [];
            }
        }, 100);
    }
}
